@@ -11,14 +11,12 @@
 #' Furthermore, for non-spatial models including endogenous 
 #' regressors ("iv"), it could be used to estimate using 
 #' instrumental variables and Feasible Generalized Least Squares.
-#'  
 #' @usage spsurgs3sls(formula = NULL, data = NULL, na.action,
 #'                   listw = NULL, zero.policy = NULL, 
 #'                   type = "slm", Durbin = FALSE,
 #'                   endog = NULL, instruments = NULL,
 #'                   lag.instr = FALSE, initial.value = 0.2, 
 #'                   het = FALSE, trace = TRUE)
-#'     
 #' @param formula An object type \code{\link[Formula]{Formula}} 
 #'   similar to objects created with the package \pkg{Formula} 
 #'   describing the equations to be estimated in the model. 
@@ -55,7 +53,7 @@
 #'   dependent variable in the same way than 
 #'   previous \emph{endog} argument.
 #' @param lag.instr should the external instruments be spatially lagged?      
-#' @param initial.value the initial value for rho. It can be either numeric
+#' @param initial.value he initial value for rho. It can be either numeric
 #'  (default is 0.2) or set to 'SAR', in which case the optimization 
 #'  will start from the estimated coefficient of a regression of 
 #'  the 2SLS residuals over their spatial lag (i.e. a spatial 
@@ -142,9 +140,9 @@
 #'
 #' @author
 #'   \tabular{ll}{
-#'   Fernando Lopez  \tab \email{fernando.lopez@@upct.es} \cr
-#'   Roman Minguez  \tab \email{roman.minguez@@uclm.es} \cr
-#'   Jesus Mur  \tab \email{jmur@@unizar.es} \cr
+#'   Fernando López  \tab \email{fernando.lopez@@upct.es} \cr
+#'   Román Mínguez  \tab \email{roman.minguez@@uclm.es} \cr
+#'   Jesús Mur  \tab \email{jmur@@unizar.es} \cr
 #'   }
 #'
 #' @references
@@ -173,7 +171,7 @@
 #'       Models with Heteroskedastic Innovations 
 #'       in R. \emph{Journal of Statistical 
 #'       Software}, 35(1), pp. 1-21. 
-#'       \url{https://www.jstatsoft.org/article/view/v035i01}
+#'       \url{https://www.jstatsoft.org/v35/i01/}. -          
 #'   }
 #'
 #' @seealso
@@ -268,8 +266,8 @@ spsurgs3sls <- function(formula = NULL, data = NULL, na.action,
       !inherits(listw, c("listw", "Matrix", "matrix")))
     stop("listw format unknown or NULL")
   if (inherits(listw, "matrix")) {
-    W <- Matrix::Matrix(listw)
-    listw <- spdep::mat2listw(W)
+    W <- as(listw, "dgCMatrix")
+    listw <- spdep::mat2listw(listw)
   }  
   if (inherits(listw, "Matrix")) {
     W <- listw
@@ -380,8 +378,9 @@ spsurgs3sls <- function(formula = NULL, data = NULL, na.action,
     colnames(Xg[[i]]) <- names(betashatg[[i]])
     pg[[i]] <- ncol(Xg[[i]])
     Zg[[i]] <- Xg[[i]]
-    W <- sphet::listw2dgCMatrix(listw, 
-                                zero.policy = zero.policy)
+    W <- as(spdep::listw2mat(listw), "dgCMatrix")
+    # W <- sphet::listw2dgCMatrix(listw, 
+    #                             zero.policy = zero.policy)
     if (model_spreg == "lag" ||  model_spreg == "sarar") {
       ## Add spatial lag of y to Zg[[i]]
       Wyg <-  W %*% yg[[i]]
@@ -572,5 +571,8 @@ spsurgs3sls <- function(formula = NULL, data = NULL, na.action,
     if (length(zero.regs) > 0L) 
       attr(ret, "zero.regs") <- zero.regs
   }
+  # if(exists("na.act")) { # It could not exist with data matrices
+  #   if (!is.null(na.act)) ret$na.action <- na.act
+  # } 
   ret  
 }
